@@ -267,6 +267,46 @@ func TestPreJoinChannels(t *testing.T) {
 	}
 }
 
+func TestServerPassword(t *testing.T) {
+	server, port := makeTestServer(t)
+	config := makeTestIRCConfig(port)
+	config.IRCHostPass = "hostsecret"
+	notifier, _ := makeTestNotifier(t, config)
+
+	var testStep sync.WaitGroup
+
+	joinHandler := func(conn *bufio.ReadWriter, line *irc.Line) error {
+		// #baz is configured as the last channel to pre-join
+		if line.Args[0] == "#baz" {
+			testStep.Done()
+		}
+		return nil
+	}
+	server.SetHandler("JOIN", joinHandler)
+
+	testStep.Add(1)
+	go notifier.Run()
+
+	testStep.Wait()
+
+	notifier.StopRunning <- true
+	server.Stop()
+
+	expectedCommands := []string{
+		"PASS hostsecret",
+		"NICK foo",
+		"USER foo 12 * :",
+		"JOIN #foo",
+		"JOIN #bar",
+		"JOIN #baz",
+		"QUIT :see ya",
+	}
+
+	if !reflect.DeepEqual(expectedCommands, server.Log) {
+		t.Error("Did not send IRC server password")
+	}
+}
+
 func TestSendAlertOnPreJoinedChannel(t *testing.T) {
 	server, port := makeTestServer(t)
 	config := makeTestIRCConfig(port)
